@@ -10,7 +10,7 @@ import Control.Monad
 import Control.Exception
 import Data.Typeable
 import System.Exit
-import System.Posix.Env
+import System.Environment
 
 import Categorize
 import TimeLog
@@ -18,7 +18,7 @@ import Data
 import Data.Time.Clock
 
 main = do
-    putEnv "TZ=UTC" -- to make tests reproducible
+    setEnv "TZ" "UTC" -- to make tests reproducible
     defaultMain tests
 
 tests :: TestTree
@@ -71,6 +71,9 @@ goldenTests = testGroup "Golden tests"
     , goldenVsString "stats small unicode"
         "tests/unicode_stats.out" $
         run "dist/build/arbtt-stats/arbtt-stats" ["--logfile", "tests/unicode.log", "--categorize", "tests/unicode.cfg"] B.empty
+    , goldenVsString "stats gap handling"
+        "tests/gap-handling.out" $
+        run "dist/build/arbtt-stats/arbtt-stats" ["--logfile", "tests/gap-handling.log", "--categorize", "tests/gap-handling.cfg", "--intervals", "Program:"] B.empty
     ]
 
 
@@ -79,7 +82,7 @@ run cmd args stdin = do
    (ex,stdout,stderr) <- readProcessWithExitCode cmd args stdin
    unless (B.null stderr) $ throwIO $ StderrException stderr
    case ex of
-     ExitSuccess   -> return stdout
+     ExitSuccess   -> return (B.filter (not . (==13)) stdout) -- windows compat
      ExitFailure r -> throwIO $ ExitCodeException r
 
 data StderrException = StderrException B.ByteString
